pub struct LaunchedLocalhostBinary { /* private fields */ }Trait Implementations
Sourceimpl Drop for LaunchedLocalhostBinary
Available on Unix only.
impl Drop for LaunchedLocalhostBinary
Available on Unix only.
Sourceimpl LaunchedBinary for LaunchedLocalhostBinary
impl LaunchedBinary for LaunchedLocalhostBinary
fn stdin(&self) -> UnboundedSender<String>
Sourcefn deploy_stdout(&self) -> Receiver<String>
fn deploy_stdout(&self) -> Receiver<String>
Provides a oneshot channel to handshake with the binary,
with the guarantee that as long as deploy is holding on
to a handle, none of the messages will also be broadcast
to the user-facing
LaunchedBinary::stdout channel.fn stdout(&self) -> UnboundedReceiver<String>
fn stderr(&self) -> UnboundedReceiver<String>
fn stdout_filter(&self, prefix: String) -> UnboundedReceiver<String>
fn stderr_filter(&self, prefix: String) -> UnboundedReceiver<String>
fn tracing_results(&self) -> Option<&TracingResults>
fn exit_code(&self) -> Option<i32>